======
mdaviz
======

Python Qt5 application to visualize mda data.

.. from gemviz
   .. list-table::
      :widths: 1 2

      * - ..  figure:: _static/gemviz_gui.png
            :alt: fig.gemviz_gui
      - * Browse catalogs of Bluesky data
         * Search for data by keywords or date
         * Visualize (1-D plots now)

.. toctree::
   :maxdepth: 1
   :hidden:

   user_guide
   install
   api

.. icons: https://fonts.google.com/icons
.. grid:: 3

    .. grid-item-card:: :material-regular:`summarize;3em` User Guide
      :link: user_guide
      :link-type: doc

    .. grid-item-card:: :material-regular:`install_desktop;3em` Install
      :link: install
      :link-type: doc

    .. grid-item-card:: :material-regular:`api;3em` API
      :link: api
      :link-type: doc


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
